import all from 'it-all';
import { encodeError } from 'ipfs-message-port-protocol/error';
import {
  decodeCID,
  encodeCID
} from 'ipfs-message-port-protocol/cid';
import { encodeBlock } from 'ipfs-message-port-protocol/block';
export class BlockService {
  constructor(ipfs) {
    this.ipfs = ipfs;
  }
  async get(query) {
    const cid = decodeCID(query.cid);
    const block = await this.ipfs.block.get(cid, query);
    const transfer = new Set();
    return {
      transfer,
      block: encodeBlock(block, transfer)
    };
  }
  async put(query) {
    const input = query.block;
    const result = await this.ipfs.block.put(input, query);
    const transfer = new Set();
    return {
      transfer,
      cid: encodeCID(result, transfer)
    };
  }
  async rm(query) {
    const transfer = new Set();
    const result = await all(this.ipfs.block.rm(query.cids.map(decodeCID), query));
    return result.map(entry => encodeRmEntry(entry, transfer));
  }
  async stat(query) {
    const cid = decodeCID(query.cid);
    const result = await this.ipfs.block.stat(cid, query);
    return {
      ...result,
      cid: encodeCID(result.cid)
    };
  }
}
const encodeRmEntry = (entry, transfer) => {
  const cid = encodeCID(entry.cid, transfer);
  if (entry.error) {
    return {
      cid,
      error: encodeError(entry.error)
    };
  } else {
    return { cid };
  }
};